/** 
 * Developer's Notice:
 * 
 * Note: CSS in this file (and this file itself) is not guaranteed backwards compatibility. Rules can be added, changed or removed at any time without notice.
 * For more information see the `Backwards Compatibility Guidelines for Developers` section of the README.md file.
 **/
 /** Generic MonsterInsights Styles **/
	/** Font from FortAwesome project. */
		@font-face{font-family: 'Misettings';src: url('../fonts/icons.eot');src: url('../fonts/icons.eot?#iefix') format('embedded-opentype'), url('../fonts/icons.woff2') format('woff2'),url('../fonts/icons.woff') format('woff'),url('../fonts/icons.ttf') format('truetype'),url('../fonts/icons.otf') format('opentype');font-weight: 400;font-style: normal;}
	
	/** Hide other plugin's error messages on our pages */
		body.monsterinsights_page div.wrap > div.error,body.monsterinsights_page div.wrap > div.notice,body.monsterinsights_page div.wrap > div.updated{margin-left:20px;margin-right:20px}
		body.monsterinsights_page .update-nag{margin-left:20px;margin-bottom:20px}

	/** Sizes/Layout **/
		body.monsterinsights_page #wpcontent{padding-left:0}
		body.monsterinsights_page div.wrap{margin:0 20px}
		body.monsterinsights_page #wpbody,body.monsterinsights_page #wpfooter,body.monsterinsights_page, body.monsterinsights_page #wpwrap{background-color:#fff}
		@media (max-width: 599px) {	
			body.monsterinsights_page #wpbody {padding-top: 0;}
		}
		
		.monsterinsights-grid{margin:0 0 50px}
		.monsterinsights-grid:after{content:"";display:table;clear:both}
		.monsterinsights-col-1-1{width:100%}
		.monsterinsights-col-7-8{width:87.5%}
		.monsterinsights-col-3-4{width:75%}
		.monsterinsights-col-2-3{width:66.66%}
		.monsterinsights-col-1-2{width:50%}
		.monsterinsights-col-1-3{width:33.33%}
		.monsterinsights-col-1-4{width:25%}
		.monsterinsights-col-1-8{width:12.5%}
		[class*="monsterinsights-col-"]{float:left;padding-right:20px;box-sizing:border-box}
		.monsterinsights-grid [class*="monsterinsights-col-"]:last-of-type{padding-right:0}

	/** Special Classes */
		.monsterinsights-hideme{display:none;visibility: hidden;}
		.monsterinsights-no-text-decoration{text-decoration:none}
		.monsterinsights-required-indicator{color: #b94a48;display: inline;}

	/** Clearfixes */
		.monsterinsights-clear{clear:both}
		.monsterinsights-clear:after{clear:both;content:'.';display:block;height:0;line-height:0;overflow:auto;visibility:hidden;zoom:1}
		.monsterinsights-clearfix{content:"";display:table;clear:both}
		.monsterinsights-clearfix-after:after{content:"";display:table;clear:both}

	/* Tooltips */
		.monsterinsights-help-tip{cursor:help}
		.monsterinsights-ui-tooltip{background:#333!important;border-width:1px!important;border-radius:3px!important;box-shadow:1px 1px 2px 1px rgba(214,214,214,0.5)!important;color:#dedede!important;max-width:300px!important;padding:7px!important;text-rendering:optimizeLegibility;text-shadow:none!important;z-index:9999!important}

	/** Buttons */
		body.monsterinsights_page .button{-webkit-border-radius:2px;-moz-border-radius:2px;-o-border-radius:2px;border-radius:2px;padding:0 16px 1px;height:33px;line-height:30px;text-decoration:none;text-shadow:none;font-weight:600;-webkit-box-shadow:none;box-shadow:none}
		body.monsterinsights_page .button.button-small{padding:0 8px 1px;line-height:22px;height:24px}
		body.monsterinsights_page .button.button-x-large{padding:0 32px 1px;line-height:48px;height:50px;font-size:18px;text-transform:uppercase}
		body.monsterinsights_page .button.show-settings{height:auto}
		body.monsterinsights_page .button.button-primary{background:#47c1a5;border-color:#3ca489;-webkit-box-shadow:none;box-shadow:none;color:#fff;border:1px solid #3ca489;-moz-border-radius:3px;-webkit-border-radius:3px;border-radius:3px;-moz-background-clip:padding;-webkit-background-clip:padding-box;background-clip:padding-box;background-color:#47c1a5}
		body.monsterinsights_page .button.button-primary:hover{background:#3ba389;border-color:#3ba389;color:#fff}
		body.monsterinsights_page .button.button-action{background:#479be7;border-color:#4182bf;-webkit-box-shadow:none;box-shadow:none;color:#fff;border:1px solid #4182bf;-moz-border-radius:3px;-webkit-border-radius:3px;border-radius:3px;-moz-background-clip:padding;-webkit-background-clip:padding-box;background-clip:padding-box;background-color:#479be7}
		body.monsterinsights_page .button.button-action:hover{background:#4183bf;border-color:#4183bf;color:#fff}
		body.monsterinsights_page .button.button-danger{background:#fff;border-color:#e3e9ed;-webkit-box-shadow:none;box-shadow:none;color:#000;border:1px solid #e3e9ed;-moz-border-radius:4px;-webkit-border-radius:4px;border-radius:4px;-moz-background-clip:padding;-webkit-background-clip:padding-box;background-clip:padding-box;background-color:#fff}
		body.monsterinsights_page .button.button-danger:hover{background:#e3e9ed;border-color:#e3e9ed;color:#000}
		@media (min-width: 600px) and (max-width: 767px) {
			body.monsterinsights_page .button{margin-top:10px}
		}
		body.monsterinsights_page .monsterinsights-action-button{align-items:flex-start;background-color:#eee;background-image:linear-gradient(#fcfcfc,#eee);border-image-outset:0;border-image-repeat:stretch;border-image-slice:100%;border-image-source:none;border-image-width:1;box-sizing:border-box;color:#333;cursor:pointer;display:block;float:left;font-family:Helvetica,arial,nimbussansl,liberationsans,freesans,clean,sans-serif,"Segoe UI Emoji","Segoe UI Symbol";font-size:13px;font-stretch:normal;font-style:normal;font-variant-caps:normal;font-variant-ligatures:normal;font-variant-numeric:normal;font-weight:700;height:33.6px;letter-spacing:normal;line-height:20px;overflow-x:visible;overflow-y:visible;position:relative;text-align:center;text-indent:0;text-rendering:auto;text-shadow:none;text-size-adjust:100%;text-transform:none;user-select:none;vertical-align:middle;white-space:nowrap;word-spacing:0;writing-mode:horizontal-tb;-webkit-appearance:none;-webkit-border-image:none;border-color:#d5d5d5;border-radius:3px;border-style:solid;border-width:.8px;margin:0;padding:6px 12px}

	/** Clipboard & Code */
		div.monsterinsights-code{position:relative;margin:0 0 10px}
		div.monsterinsights-code:after{content:"";display:table;clear:both}
		div.monsterinsights-code code{display:block;font-size:11px;padding:5px 20px 5px 5px}
		a.monsterinsights-clipboard{position:absolute;top:5px;right:5px;color:#23282d;width:33px;padding:0}
		a.monsterinsights-clipboard span{display:block;text-indent:-9999px}

	/* Page Header */
		/* Banner + Background */
			#monsterinsights-header-temp{position:relative;margin:0}
			#monsterinsights-header{background-color:#f3f5ff;background-image:url(images/waves.png);background-repeat:no-repeat;margin:0;height:119px}
			@media only screen and (min--moz-device-pixel-ratio: 2),only screen and (-o-min-device-pixel-ratio: 21),only screen and (-webkit-min-device-pixel-ratio: 2),only screen and (min-device-pixel-ratio: 2) {
				#monsterinsights-header{background-image:url(images/waves@x2.png);background-size:1356px 119px}
			}
		
		/* Title + Mascot */
			.monsterinsights-header-title{padding-top:50px;padding-left:20px;margin:0}
			.monsterinsights-header-mascot{float:right;position:absolute;top:0;right:0;margin-top:10px;margin-right:20px;z-index:100}

		/* Media Queries */
			@media (max-width: 610px) {
				.monsterinsights-header-mascot{display:none}
				.monsterinsights-header-title{padding-top:70px}
				#monsterinsights-addon-heading form{margin-right:0}
			}

		/* Messages */
			/* Generic */
				.monsterinsights-notice{border:1px solid;-moz-border-radius:5px;-webkit-border-radius:5px;border-radius:5px;-moz-background-clip:padding;-webkit-background-clip:padding-box;background-clip:padding-box;box-sizing:border-box;display:table; width: 100%; margin: 10px 0px;}
				.monsterinsights-notice:after{content:"";display:table;clear:both}
				.monsterinsights-notice-icon{padding:20px;box-sizing:border-box;width:60px;color:#fff;font-family:"Misettings";font-size:18px;-moz-border-radius:5px 0 0;-webkit-border-radius:5px 0 0;border-radius:5px 0 0;-moz-background-clip:padding;-webkit-background-clip:padding-box;background-clip:padding-box;display:table-cell;vertical-align: middle;text-align: center;}
				.monsterinsights-notice-text{color:#434751;font-size:16px;font-weight:700;padding: 20px;box-sizing:border-box;word-wrap:break-word;display:table-cell;position: relative;vertical-align: middle;}
				body.monsterinsights_page div.wrap > div.error,body.monsterinsights_page div.wrap > div.notice,body.monsterinsights_page div.wrap > div.updated{margin-left:0;margin-right:0}
				.monsterinsights-notice .button { margin: 0px 0px 1em 0px }
				.monsterinsights-notice-message{margin:0px;}

			/* Alert */
				.monsterinsights-alert-notice-icon{background-color:#fdbf2f;}
				.monsterinsights-alert-notice-icon:before{content: '\f017';}
				.monsterinsights-alert-notice{border-color:#fdbf2f;background-color:rgba(253,192,47,0.1)}

			/* Error */
				.monsterinsights-error-notice-icon{background-color:#df4228;}
				.monsterinsights-error-notice-icon:before{content: '\f014';}
				.monsterinsights-error-notice{border-color:#df4228;background-color:rgba(224,66,40,0.1)}

			/* Info */
				.monsterinsights-info-notice-icon{background-color:#479be7;}
				.monsterinsights-info-notice-icon:before{content: '\f016';}
				.monsterinsights-info-notice{border-color:#479be7;background-color:rgba(72,155,232,0.1)}

			/* Success */
				.monsterinsights-success-notice-icon{background-color:#47c1a5;}
				.monsterinsights-success-notice-icon:before{content: '\f015';}
				.monsterinsights-success-notice{border-color:#47c1a5;background-color:rgba(71,194,165,0.1)}

			/* Dismiss Notice */
				.monsterinsights-notice p.monsterinsights-intro{border:none!important;margin:0 0 20px!important;padding:0!important}
				.monsterinsights-notice .notice-dismiss{top:10px;right:10px;color:#000}
				.monsterinsights-notice .notice-dismiss:before{color:#000;width:26px;height:26px;font-size:22px}

	/** Other */


/** MonsterInsights Icons **/
	/** Generic Icons Styles **/
		[class*='monstericon-']:before{display:inline-block;font-family:'Misettings';font-style:normal;font-weight:400;line-height:50px;padding-right:12px;padding-left:5px;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;vertical-align:middle;font-size: 20px}
		[class*='monstericon-'].monsterinsights-active:before{color:#479be7}
		[class*='monstericon-']:active:before{color:#479be7}
		[class*='monstericon-']:hover:before{color:#479be7}



	/** Defined Icons **/
		.monstericon-ads:before{content:'\0041'}
		.monstericon-affiliates:before{content:'\0042'}
		.monstericon-compatibility:before{content:'\0043'}
		.monstericon-demographics:before{content:'\0044'}
		.monstericon-dimensions:before{content:'\0045'}
		.monstericon-files:before{content:'\0046'}
		.monstericon-ecommerce:before{content:'\0047'}
		.monstericon-engagement:before{content:'\0048'}
		.monstericon-forms:before{content:'\0049'}
		.monstericon-links:before{content:'\004a'}
		.monstericon-memberships:before{content:'\004b'}
		.monstericon-notifications:before{content:'\004c'}
		.monstericon-performance:before{content:'\004d'}
		.monstericon-permissions:before{content:'\004e'}
		.monstericon-reporting:before{content:'\004f'}
		.monstericon-social:before{content:'\0050'}
		.monstericon-media:before{content:'\0051'}
		.monstericon-amp:before{content:'\f000'}
		.monstericon-goptimize:before{content:'\f002'}
		.monstericon-fbia:before{content:'\f001'}
		.monstericon-bounce:before{content:'\0051'} /* Todo: Update with icons from Jonathon */
		.monsterinsights-upgrade-menu-icon{float:right;color:#7f8591;font-size:10px;font-weight:700;text-transform:uppercase;line-height:1;display:inline-block;padding:6px 12px;background-color:#fff;border-radius:3px;margin-right:18px;margin-top:15px}
		.monsterinsights-main-nav-item.monsterinsights-active .monsterinsights-upgrade-menu-icon,.monsterinsights-main-nav-item:hover .monsterinsights-upgrade-menu-icon{background-color:#f7f8fa}

	/* Icon Media Queries **/
		@media only screen and (max-width: 767px) {
			[class*='monstericon-']:before{ display: none !important;content: '';}
			span.monsterinsights-upgrade-menu-icon{display:none}
		}

/** Navigation Styles **/
	/** Nav Container **/
		/** Generic **/
			.monsterinsights-nav-container{border:0;background-color:#615d9b;margin:0;display:table;width:100%}
			h1.monsterinsights-nav-container { padding: 0px;}

		/** Main Nav Container **/
			.monsterinsights-main-nav-container{ height:50px;}

		/** Sub Nav Container **/
			.monsterinsights-sub-nav-container{display:table-cell;float:none;vertical-align:top;background-color:#f7f8fa;float:left;width:290px;margin:0;padding:0;border-left:1px solid #e4e9ee;border-top:1px solid #e4e9ee;border-bottom:1px solid #e4e9ee;border-right:1px solid #e4e9ee;border-collapse:collapse;border-top-left-radius:3px;border-bottom-left-radius:3px}

	/** Nav Item **/
		/** Generic **/
			.monsterinsights-nav-item{border:none;float:left;text-decoration: none;}
			.monsterinsights-nav-item:focus,.monsterinsights-nav-item:active{box-shadow: none;}

		/** Main Nav Item **/
			.monsterinsights-main-nav-item{background-color:#615d9b;color:#d8d7e4;background:none;line-height:50px;font-size:13px;padding:0 15px;margin:0;width:100px;text-align:center}
			.monsterinsights-main-nav-item.monsterinsights-spacing-item{width:5px;padding-left: 0;}
			.monsterinsights-main-nav-item.monsterinsights-active{color:#434751;opacity:1;background-color:#fff}
			.monsterinsights-main-nav-item:hover:not(.monsterinsights-active),.monsterinsights-main-nav-item:active:not(.monsterinsights-active){color:#fff;opacity:1}
			.monsterinsights-main-nav-container > .monsterinsights-main-nav-item:not(.monsterinsights-active) + a.monsterinsights-main-nav-item:not(.monsterinsights-active) {border-left: 1px solid #8c8ab5;}
			.monsterinsights-main-nav-container > .monsterinsights-main-nav-item:last-child:not(.monsterinsights-active) {border-right: 1px solid #8c8ab5;}
			.monsterinsights-main-nav-item.monsterinsights-active{border:0 !important}

		/** Sub Nav Item **/
			.monsterinsights-sub-nav-item{font-size:13px;background-color:#f7f8fa;font-weight:500;line-height:50px;width:100%;margin:0;padding:5px 15px 5px 15px;text-decoration:none;color:#7f8591;border-bottom:1px solid #e4e9ee;border-right:none;-webkit-box-sizing:border-box;-moz-box-sizing:border-box;box-sizing:border-box;transition:none;box-shadow:none;-webkit-box-shadow:none;-webkit-transition:none;}
			.monsterinsights-sub-nav-item.monsterinsights-active,.monsterinsights-sub-nav-item:hover,.monsterinsights-sub-nav-item:active{border-right:1px solid #fff;background-color:#fff;color:#444851}

	/** Nav Tab Container **/
		/** Generic **/
			.monsterinsights-sub-nav-area { display: flex;} /* Holds Sub nav menu and tabs */
			.monsterinsights-nav-tabs{}

		/** Main Nav Tab Container **/
			.monsterinsights-main-nav-tabs{}

		/** Sub Nav Tab Container **/
			.monsterinsights-sub-nav-tabs{float:left;display:table-cell;float:none;vertical-align:top;background-color:#f7f8fa;border-top:1px solid #e4e9ee;border-right:1px solid #e4e9ee;border-bottom:1px solid #e4e9ee;-webkit-box-sizing:border-box;-moz-box-sizing:border-box;box-sizing:border-box;transition:none;box-shadow:none;-webkit-box-shadow:none;-webkit-transition:none;border-top-right-radius:3px;border-bottom-right-radius:3px;width:100%;}

	/** Nav Tab **/
		/** Generic **/
			.monsterinsights-nav-tab{display:none;}
			.monsterinsights-nav-tab.monsterinsights-active{display:block}
			.monsterinsights-nav-tab .description{color:#7f8592;font-size:13px;margin-top:10px}

		/** Main Nav Tab **/
			.monsterinsights-main-nav-tab{}
			.monsterinsights-main-nav-tab .form-table tr{border-bottom:1px solid #ddd}
			.monsterinsights-main-nav-tab .form-table tr.no-bottom-border{border-bottom:0}

		/** Sub Nav Tab **/
			.monsterinsights-sub-nav-tab{margin:15px 0 20px;}
			.monsterinsights-sub-nav-tab .form-table tr{border-bottom:1px solid #ddd}
			.monsterinsights-sub-nav-tab .form-table tr.no-bottom-border{border-bottom:0}

	/** Nav Media Queries **/
		.monsterinsights-main-nav-tabs .form-table th,.monsterinsights-main-nav-tabs .form-table td {padding-top: 40px;padding-bottom: 40px;}
		.monsterinsights-sub-nav-tabs .form-table th,.monsterinsights-sub-nav-tabs .form-table td {	padding-top: 40px;}
		@media (min-width: 768px) and (max-width: 991px) {
			.monsterinsights-main-nav-tabs .form-table th,.monsterinsights-sub-nav-tabs .form-table th{padding-top:40px;padding-right:0!important}
			.monsterinsights-main-nav-tabs .form-table td,.monsterinsights-sub-nav-tabs .form-table td{padding-right:0}
		}
		@media (min-width: 600px) and (max-width: 767px) {
			.monsterinsights-main-nav-tabs .form-table th, .monsterinsights-sub-nav-tabs .form-table th{padding-top:40px;padding-bottom:10px;padding-right:0!important}
			.monsterinsights-main-nav-tabs .form-table td,.monsterinsights-sub-nav-tabs .form-table td{padding-top:0;padding-right:0}
		}
		@media only screen and (max-width: 610px) {
			.monsterinsights-main-nav-tabs .form-table th, .monsterinsights-sub-nav-tabs .form-table th{padding-top:20px;padding-bottom:10px;padding-right:0px}
			.monsterinsights-main-nav-tabs .form-table td,.monsterinsights-sub-nav-tabs .form-table td{padding-top:0;padding-bottom:20px;padding-right:0px}
			.monsterinsights-main-nav-item{width:auto}
			.monsterinsights-main-nav-item.monsterinsights-spacing-item{display:none}
			h1.monsterinsights-nav-container { padding: 0px; min-width: 150px;}
			.monsterinsights-sub-nav-tabs th{width:auto}
		}
		@media only screen and (max-width: 767px) {
			.monsterinsights-sub-nav-container{width:100%}
			.monsterinsights-sub-nav-item{padding:0;text-align:center;width:100%!important;padding:0;text-align:center}
			.monsterinsights-sub-nav-tabs .form-table th,.monsterinsights-sub-nav-tabs .form-table td{padding:10px 0!important}
			h1.monsterinsights-nav-container { padding: 0px;}
		}

/** Settings Page Styles **/
	/** Generic Settings Page Styles **/
		div#monsterinsights-settings-sub-pages{padding-left:20px;background-color:#FFF;padding-right:20px}
		#monsterinsights-settings-pages{padding:20px 0}
		.monsterinsights-main-nav-tabs label{margin-top:7px;display:block;color:#444851}
		.monsterinsights-sub-nav-tabs label{margin-top:7px;display:block}
		#monsterinsights-settings-pages #monsterinsights-settings-submit{margin:40px 0 0 0px}
		#monsterinsights-settings-pages #monsterinsights-refresh-submit{margin-left:10px;vertical-align:baseline;}
		input.monsterinsights-large-checkbox{zoom:1.5}
		#monsterinsights-settings-pages input[type="text"],#monsterinsights-settings-pages input[type="number"],#monsterinsights-settings-pages input[type="password"],#monsterinsights-settings-pages input[type=email], #monsterinsights-settings-pages select,#monsterinsights-settings-pages textarea{width:350px;padding-right:0;font-size:13px;border-width:2px;border-radius:3px;border-color:#e4e9ee;box-shadow:none}
		#monsterinsights-settings-pages input[type="text"],#monsterinsights-settings-pages input[type="number"],#monsterinsights-settings-pages input[type="password"],#monsterinsights-settings-pages input[type=email]{height:32px;}
		@media (max-width: 767px) {
			#monsterinsights-settings-pages input[type="text"],#monsterinsights-settings-pages input[type="number"],#monsterinsights-settings-pages input[type="password"], #monsterinsights-settings-pages input[type=email], #monsterinsights-settings-pages select,#monsterinsights-settings-pages textarea{width:90%!important}
			#monsterinsights-settings-pages input[type="text"],#monsterinsights-settings-pages input[type="number"],#monsterinsights-settings-pages input[type="password"], #monsterinsights-settings-pages input[type=email]{height:auto;}
		}

	/** General Tab Styles **/
		/** License Key Styles */
			@media (min-width: 768px) and (max-width: 991px) {
				tr#monsterinsights-settings-key-box th{padding-top:20px}
			}
			@media (min-width: 600px) and (max-width: 767px) {
				tr#monsterinsights-settings-key-box th{padding-top:20px}
			}
			
		/** GA Auth Styles */
			/** Container */
				.monsterinsights_opacity_60{opacity:.6}
				#monsterinsights_google_auth_view{color:#000;font-family:"proxima-nova","Helvetica Neue",sans-serif;-webkit-transition:opacity 1s;-moz-transition:opacity 1s;-o-transition:opacity 1s;transition:opacity 1s;text-align:center;-webkit-perspective:700px;-webkit-perspective-origin:320px 700px;margin:0 auto;height:588px;width:400px;overflow:hidden;max-width:100%;margin:auto;top:0;left:0;bottom:0;right:0;position:absolute;z-index:301;-moz-border-radius:10px;-webkit-border-radius:10px;border-radius:10px;-moz-background-clip:padding;-webkit-background-clip:padding-box;background-clip:padding-box;background-color:#f3f5ff;-moz-box-shadow:0 0 43px rgba(97,93,155,.23);-webkit-box-shadow:0 0 43px rgba(97,93,155,.23);box-shadow:0 0 43px rgba(97,93,155,.23)}

			/** Backgrounds */
				.monsterinsights_google_auth_start_view{background-image:url(../images/gauth-1-of-3.png);background-repeat:no-repeat}
				.monsterinsights_google_auth_exit_view{background-image:url(../images/gauth-exit.png);background-repeat:no-repeat}
				.monsterinsights_google_auth_enterkey_view{background-image:url(../images/gauth-2-of-3.png);background-repeat:no-repeat}
				.monsterinsights_google_auth_selectprofile_view{background-image:url(../images/gauth-3-of-3.png);background-repeat:no-repeat}
				.monsterinsights_google_auth_done_view{background-image:url(../images/gauth-done.png);background-repeat:no-repeat}
				.monsterinsights_google_auth_reauth_start_view{background-image:url(../images/gauth-warn-1-of-3.png);background-repeat:no-repeat}
				.monsterinsights_google_auth_reauth_exit_view{background-image:url(../images/gauth-warn-exit.png);background-repeat:no-repeat}
				.monsterinsights_google_auth_reauth_enterkey_view{background-image:url(../images/gauth-warn-2-of-3.png);background-repeat:no-repeat}
				.monsterinsights_google_auth_reauth_selectprofile_view{background-image:url(../images/gauth-warn-3-of-3.png);background-repeat:no-repeat}
				.monsterinsights_google_auth_reauth_done_view{background-image:url(../images/gauth-warn-done.png);background-repeat:no-repeat}
				@media only screen and (min--moz-device-pixel-ratio: 2),only screen and (-o-min-device-pixel-ratio: 21),only screen and (-webkit-min-device-pixel-ratio: 2),only screen and (min-device-pixel-ratio: 2) {
					.monsterinsights_google_auth_start_view{background-image:url(../images/gauth-1-of-3@2x.png);background-size:400px 588px}
					.monsterinsights_google_auth_exit_view{background-image:url(../images/gauth-exit@2x.png);background-size:400px 588px}
					.monsterinsights_google_auth_enterkey_view{background-image:url(../images/gauth-2-of-3@2x.png);background-size:400px 588px}
					.monsterinsights_google_auth_selectprofile_view{background-image:url(../images/gauth-3-of-3@2x.png);background-size:400px 588px}
					.monsterinsights_google_auth_done_view{background-image:url(../images/gauth-done@2x.png);background-size:400px 588px}
					.monsterinsights_google_auth_reauth_start_view{background-image:url(../images/gauth-warn-1-of-3@2x.png);background-size:401px 651px}
					.monsterinsights_google_auth_reauth_exit_view{background-image:url(../images/gauth-warn-exit@2x.png);background-size:401px 651px}
					.monsterinsights_google_auth_reauth_enterkey_view{background-image:url(../images/gauth-warn-2-of-3@2x.png);background-size:401px 651px}
					.monsterinsights_google_auth_reauth_selectprofile_view{background-image:url(../images/gauth-warn-3-of-3@2x.png);background-size:401px 651px}
					.monsterinsights_google_auth_reauth_done_view{background-image:url(../images/gauth-warn-done@2x.png);background-size:401px 651px}
				}

			/** Header/Footer */
				#monsterinsights_google_auth_block_view{position:fixed;background:rgba(243,246,255,.9);top:0;right:0;bottom:0;left:0;z-index:300}
				#monsterinsights_google_auth_box_header{height:80px;width:100%}
				#monsterinsights_google_auth_box_contents{height:187px;padding-top:321px;width:100%}
				#monsterinsights_google_auth_box_contents.monsterinsights_google_auth_reauth{padding-top:303px}
				#monsterinsights_google_auth_box_footer{height:80px;width:100%}
				.monsterinsights_google_auth_box_header_reauth{color:#434751;font-size:14px;padding-left:90px;padding-top:23px;text-align:left}
				.monsterinsights_google_auth_box_header_reauth .monsterinsights_google_auth_box_cancel{color:#FFF;opacity:1}
				.monsterinsights_google_auth_start_view_description{color:#7f8591;font-size:14px;padding-bottom:40px}
				.monsterinsights_google_auth_view_title{color:#434751;font-size:20px;padding-bottom:27px}
				.monsterinsights_google_auth_box_cancel:hover{color:#fff;font-size:16px;font-weight:700;text-decoration:none;opacity:1}
				.monsterinsights_google_auth_box_cancel{opacity:.5;color:#fff;font-size:16px;font-weight:700;text-decoration:none}
				#monsterinsights_google_auth_box_footer_center{width:175px;float:left}
				#monsterinsights_google_auth_box_footer_left,#monsterinsights_google_auth_box_footer_right{width:125px;float:left}
				div#monsterinsights_google_auth_box_footer_right_next{padding-top:13px}
				#monsterinsights_google_auth_box_footer_right{color:#fff;font-size:16px;font-weight:700;margin-top:20px;width:85px;height:45px}
				#monsterinsights_google_auth_box_footer_right:hover{background-color:#524e86}
				.monsterinsights_google_auth_box_cancel_error:focus,.monsterinsights_google_auth_box_cancel_error,.monsterinsights_google_auth_box_done:focus,.monsterinsights_google_auth_box_done,.monsterinsights_google_auth_box_next:focus,.monsterinsights_google_auth_box_next{text-decoration:none;color:#fff}
				.monsterinsights_google_auth_box_cancel_error:hover,.monsterinsights_google_auth_box_done:hover,.monsterinsights_google_auth_box_next:hover{-moz-border-radius:2px;-webkit-border-radius:2px;border-radius:2px;margin-top:10px;color:#fff}
				#monsterinsights_google_auth_box_footer_left{padding-top:34px}

			/** Misc Styles */
				#monsterinsights-google-oauth-window{width:80%;margin-right:10%;margin-left:10%;margin-bottom:10px}
				#monsterinsights_google_auth_view.monsterinsights_google_auth_reauth{height:650px}
				.monsterinsights_google_auth_step_data_enterkey_view{width:80%;margin-right:10%;margin-left:10%;height:30px;margin-top:10px}
				.monsterinsights-google-loading{width:100%;height:100%;background-color:#FFF;color:#000;font-size:30px;padding-top:30px}
				body.monsterinsights_page .select300-drop{z-index:302 !important}

	/** Tracking Tab Styles **/
		/** Upgrade CSS */
			.monsterinsights-upsell-under-box{background-color:#f6fbff;border:1px solid #d6ecff;border-radius:3px;padding:10px 20px;margin-top:30px;}
			.monsterinsights-upsell-box{background-color:#f6fbff;border:1px solid #d6ecff;border-radius:3px;padding:10px 20px}
			a.monsterinsights-upsell-box-button.button.button-primary{margin-top:20px}
			.monsterinsights-no-settings-shown td{ padding: 5px 0px 0px 0px !important}
			.monsterinsights-no-settings-shown tr{ border:none !important}
			#monsterinsights-settings-pages p.monsterinsights-upsell-button-par{margin-bottom: 1em}
			.monsterinsights-upsell-lite-text{font-size: 14px; margin-bottom:2px;}
			
	/** Status Tab Styles **/

	/** Support Tab Styles **/

	/** Settings Page Media Queries **/

/** Dashboard Page Styles **/
	/** Dashboard Page Styles **/

	/** Dashboard Page Media Queries **/

/** Reports Page Styles **/
	/** Generic Reports Page Styles **/
		.monsterinsights-reports-action-bar-title{font-size:24px;font-weight:700;float:left}
		#monsterinsights-reports-pages{margin-top:30px}
		.monsterinsights-grid-border{border:1px solid #e3e9ed;-moz-border-radius:5px;-webkit-border-radius:5px;border-radius:5px}
		.monsterinsights-grid-grey-bg{background-color:#f7f7f9;-moz-background-clip:padding;-webkit-background-clip:padding-box;background-clip:padding-box}
		@media (max-width: 600px) {
			.monsterinsights-grid > .monsterinsights-col-1-2{width:100%;margin-top:50px}
		}

	/** Overview Report Styles **/
		.monsterinsights-data-row{width:100%;float:left;box-sizing:border-box;text-overflow:ellipsis;overflow:hidden;white-space:nowrap;color:#7f8591;padding:10px 15px}
		.monsterinsights-data-row .monsterinsights-col-7-8{text-overflow:ellipsis;overflow:hidden;white-space:nowrap}
		.monsterinsights-reports-box-datalist .monsterinsights-data-row:nth-child(odd){background-color:#f7f7f9}
		.monsterinsights-reports-box-title{background-color:#FFF;color:#7f8591;font-size:14px;font-weight:700;padding:20px;border-bottom:1px solid #e3e9ed;border-top-left-radius:5px;border-top-right-radius:5px}
		.monsterinsights-reports-box-datagraph{border:1px solid #e3e9ed;-moz-border-radius:5px;-webkit-border-radius:5px;border-radius:5px;-moz-background-clip:padding;-webkit-background-clip:padding-box;background-clip:padding-box;background-color:#fff;margin:20px;width:auto;padding:20px}
		.monsterinsights-no-padding-right{padding-right:0}
		.monsterinsights-datalist-box-title{color:#7f8591;font-size:14px;font-weight:700;margin-bottom:10px}
		.monsterinsights-reports-action-bar{padding-bottom:40px;margin-top:40px}
		.monsterinsights-reports-action-bar-actions{float:right}
		#monsterinsights-chartjs-tooltip{opacity:1;position:absolute;-webkit-transition:all .1s ease;transition:all .1s ease;pointer-events:none;-webkit-transform:translate(-50%,0);transform:translate(-50%,0);border:1px solid #e3e9ed;-moz-border-radius:3px;-webkit-border-radius:3px;border-radius:3px;-moz-background-clip:padding;-webkit-background-clip:padding-box;background-clip:padding-box;background-color:#fff;-moz-box-shadow:0 0 20px rgba(97,93,155,.13);-webkit-box-shadow:0 0 20px rgba(97,93,155,.13);box-shadow:0 0 20px rgba(97,93,155,.13);color:#434751;font-size:18px;font-weight:700;padding:8px!important}
	/** Reports Page Media Queries **/

/** Tools Page Styles **/
	/** Generic Tools Page Styles **/
		#monsterinsights-tools-pages .monsterinsights-main-nav-tab { padding: 30px 5px;margin: 0px; }
		#monsterinsights-tools-pages .monsterinsights-main-nav-tab .monsterinsights-upsell-under-box{ margin-top: 0px; }
		
	/** URL Generator Tab Styles **/
		.monsterinsights-main-nav-tabs label{margin-top:7px;display:block;color:#444851}
		#monsterinsights-tools-pages .form-table th,#monsterinsights-tools-pages .form-table td,#monsterinsights-tools-pages .form-table tr{ padding: 0px 0px 20px 0px; border: none;}
		#monsterinsights-tools-pages .monsterinsights-nav-tab .description { margin-top: 0px; }
		#monsterinsights-tools-pages input[type="text"],#monsterinsights-tools-pages input[type=url],#monsterinsights-tools-pages textarea{width:350px;padding-right:0;font-size:13px;border-width:2px;border-radius:3px;border-color:#e4e9ee;box-shadow:none;}
		#monsterinsights-tools-pages input[type="text"],#monsterinsights-tools-pages input[type=url]{height:32px;}
		#monsterinsights-tools-pages textarea{ height: 100px;}
		@media (max-width: 767px) {
			#monsterinsights-tools-pages input[type="text"],#monsterinsights-tools-pages input[type="url"],#monsterinsights-tools-pages textarea{width:90%!important;}
			#monsterinsights-tools-pages input[type="text"],#monsterinsights-tools-pages input[type="url"]{height:auto;}
		}
		#monsterinsights-related-resources-list{ list-style-type: disc; padding-left: 40px;}
	/** Import/Export Tab Styles **/

	/** Tools Page Media Queries **/

/** Addons Page Styles **/
	/** Addons Font */
		@font-face{font-family:'monsterinsights';src:url(../fonts/monsterinsights.eot);src:url(../fonts/monsterinsights.eot?#iefix) format("embedded-opentype"),url(../fonts/monsterinsights.woff) format("woff"),url(../fonts/monsterinsights.ttf) format("truetype"),url(../fonts/monsterinsights.svg#monsterinsights) format("svg");font-weight:400;font-style:normal}
		#monsterinsights-addons [class*='monsterinsights-']:before{display:inline-block;font-family:'monsterinsights';font-style:normal;font-weight:400;line-height:1;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}
		#monsterinsights-addons .monsterinsights-configuration:before{content:'\0041'}
		#monsterinsights-addons .monsterinsights-leaf:before{content:'\0042'}
		#monsterinsights-addons .monsterinsights-lightbox:before{content:'\0044'}
		#monsterinsights-addons .monsterinsights-misc:before{content:'\0045'}
		#monsterinsights-addons .monsterinsights-mobile:before{content:'\0046'}
		#monsterinsights-addons .monsterinsights-pagination:before{content:'\0047'}
		#monsterinsights-addons .monsterinsights-proofing:before{content:'\0048'}
		#monsterinsights-addons .monsterinsights-slideshow:before{content:'\0049'}
		#monsterinsights-addons .monsterinsights-tags:before{content:'\004a'}
		#monsterinsights-addons .monsterinsights-thumbnails:before{content:'\004b'}
		#monsterinsights-addons .monsterinsights-video:before{content:'\004c'}
		#monsterinsights-addons .monsterinsights-watermark:before{content:'\004d'}
		#monsterinsights-addons .monsterinsights-cloud-download:before{content:'\004e'}
		#monsterinsights-addons .monsterinsights-toggle-on:before{content:'\004f'}
		#monsterinsights-addons .monsterinsights-plus-circle:before{content:'\0050'}
		#monsterinsights-addons .monsterinsights-down-arrow:before{content:'\0051'}
		#monsterinsights-addons .monsterinsights-list:before{content:'\0052'}
		/* #monsterinsights-addons .monsterinsights-grid:before{content:'\0053'}*/
		#monsterinsights-addons .monsterinsights-pinterest-p:before{content:'\0054'}
		#monsterinsights-addons .monsterinsights-pencil:before{content:'\0055'}
		#monsterinsights-addons .monsterinsights-close:before{content:'\0056'}
		#monsterinsights-addons .monsterinsights-check:before{content:'\0057'}

	/** Generic Addons Page Styles **/
		body.monsterinsights_page .monsterinsights-addons-subheading{background-color:#fff;height:45px;margin-left:-20px}
		body.monsterinsights_page .monsterinsights-addons-subheading h1{font-size:20px;font-weight:400;line-height:45px;margin:0 0 0 20px;padding-left:20px}
		@media (min-width: 600px) and (max-width: 767px) {
			body.monsterinsights_page .monsterinsights-addons-subheading{height:auto;padding-bottom:20px}
		}
		#monsterinsights-addon-heading:after{content:"";display:table;clear:both}
		#monsterinsights-addon-heading h1{float:left}
		#monsterinsights-addon-heading form{float:right;margin-right:100px}
		@media (min-width: 600px) and (max-width: 767px) {
			#monsterinsights-addon-heading h1{float:none}
		}
		@media (max-width: 508px) {
			#monsterinsights-addon-heading form{display:none}
		}
		@media (max-width: 600px) {
			.monsterinsights-addon .interior{display:none!important}
		}
		#monsterinsights-addon-heading form input{border:1px solid #ddd;-webkit-border-radius:3px;-moz-border-radius:3px;-o-border-radius:3px;border-radius:3px;background-color:#fff;color:#666;margin:7px 10px 0 5px;font-size:14px;padding:5px 8px}
		#monsterinsights-addon-heading form select{margin:-5px 20px 0 0}
		#monsterinsights-addon-heading form .spinner{float:none;margin:-3px auto auto}
		@media (min-width: 600px) and (max-width: 767px) {
			#monsterinsights-addon-heading form{float:none;display:table;margin:10px auto 0}
		}

		#monsterinsights-addons{padding:0px;}
		#monsterinsights-addons .button,#monsterinsights-addons .button-primary{text-shadow:none;background-color:#f7f7f7;color:#23282d;font-weight:600;border:1px solid #ccc;line-height:inherit;height:inherit;padding:5px 15px;box-shadow:none;cursor:pointer}
		#monsterinsights-addons .button:hover,#monsterinsights-addons .button-primary:hover{color:#23282d;background-color:#fafafa;border-color:#999}
		#monsterinsights-addons .monsterinsights-addon-action-button{padding-left:20px;padding-right:20px}
		#monsterinsights-addons .monsterinsights-addon-action-button .monsterinsights-cloud-download{font-size:19px;float:left;margin-right:8px;color:#8d8f92}
		#monsterinsights-addons .monsterinsights-addon-action-button .monsterinsights-toggle-on{font-size:19px;float:left;margin-right:8px;margin-top:1px;color:#7cc048}
		#monsterinsights-addons .monsterinsights-addon-upgrade-button{background-color:#7cc048;color:#fff;float:none!important;margin:0 auto;display:table;line-height:25px}
		#monsterinsights-addons .monsterinsights-addon-upgrade-button:hover{background-color:#95dc5e;color:#fff;border-color:#95dc5e}
		#monsterinsights-addons .monsterinsights-addon-action-button.monsterinsights-activate-addon .monsterinsights-toggle-on{color:#e92c21;-moz-transform:scaleX(-1);-o-transform:scaleX(-1);-webkit-transform:scaleX(-1);transform:scaleX(-1);filter:FlipH;-ms-filter:FlipH}
		#monsterinsights-addons .monsterinsights-addon-title{margin-top:30px}
		#monsterinsights-addons .monsterinsights-addons-area:after{content:"";display:table;clear:both}
		#monsterinsights-addons .monsterinsights-addons-area.licensed{margin:20px 0 40px;padding:0 0 20px;border-bottom:1px solid #ddd}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon{border:1px solid #ddd;position:relative;background:#fff;border-radius:3px;float:left;margin:0 2% 2% 0;min-height:465px;padding:0;text-align:center;width:32%;box-sizing:border-box;-webkit-box-sizing:border-box;-moz-box-sizing:border-box}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon:nth-child(3n){margin-right:0}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon:nth-child(3n+1){clear:both}
		@media (min-width: 992px) and (max-width: 1199px) {
			#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon{min-height:420px}
		}
		@media (min-width: 768px) and (max-width: 991px) {
			#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon{width:100%!important;min-height:525px}
		}
		@media (min-width: 600px) and (max-width: 767px) {
			#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon{width:100%!important;min-height:525px}
		}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-thumb{margin:20px auto;max-width:100%}
		@media (min-width: 992px) and (max-width: 1199px) {
			#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-thumb{margin:10px auto 15px}
		}
		@media (min-width: 768px) and (max-width: 991px) {
			#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-thumb{margin:10px auto 15px}
		}
		@media (min-width: 600px) and (max-width: 767px) {
			#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-thumb{margin:10px auto 15px}
		}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-excerpt{color:#2f2f2f;font-weight:400;padding:0 20px;display:table;margin:0 0 90px}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message{background:#f7f7f7;border-top:1px solid #ddd}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message,#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error{position:absolute;bottom:0;float:left;width:100%;-moz-border-radius:3px;-webkit-border-radius:3px;border-radius:3px;margin:0;padding:0;text-align:left}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message .interior,#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error .interior{padding:20px}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message .interior:after,#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error .interior:after{content:"";display:table;clear:both}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message.monsterinsights-addon-active .addon-status span,#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error.monsterinsights-addon-active .addon-status span{color:#7cc048}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message.monsterinsights-addon-active .interior.monsterinsights-addon-active .addon-status span,#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error.monsterinsights-addon-active .interior.monsterinsights-addon-active .addon-status span{color:#7cc048}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message.monsterinsights-addon-active .interior.monsterinsights-addon-inactive .addon-status span,#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error.monsterinsights-addon-active .interior.monsterinsights-addon-inactive .addon-status span{color:#e82c20}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message.monsterinsights-addon-active .interior.monsterinsights-addon-not-installed .addon-status span,#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error.monsterinsights-addon-active .interior.monsterinsights-addon-not-installed .addon-status span{color:#a3a4a5}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message.monsterinsights-addon-inactive .addon-status span,#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error.monsterinsights-addon-inactive .addon-status span{color:#e82c20}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message.monsterinsights-addon-inactive .interior.monsterinsights-addon-active .addon-status span,#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error.monsterinsights-addon-inactive .interior.monsterinsights-addon-active .addon-status span{color:#7cc048}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message.monsterinsights-addon-inactive .interior.monsterinsights-addon-inactive .addon-status span,#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error.monsterinsights-addon-inactive .interior.monsterinsights-addon-inactive .addon-status span{color:#e82c20}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message.monsterinsights-addon-inactive .interior.monsterinsights-addon-not-installed .addon-status span,#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error.monsterinsights-addon-inactive .interior.monsterinsights-addon-not-installed .addon-status span{color:#a3a4a5}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message.monsterinsights-addon-not-installed .addon-status span,#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error.monsterinsights-addon-not-installed .addon-status span{color:#a3a4a5}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message.monsterinsights-addon-not-installed .interior.monsterinsights-addon-active .addon-status span,#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error.monsterinsights-addon-not-installed .interior.monsterinsights-addon-active .addon-status span{color:#7cc048}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message.monsterinsights-addon-not-installed .interior.monsterinsights-addon-inactive .addon-status span,#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error.monsterinsights-addon-not-installed .interior.monsterinsights-addon-inactive .addon-status span{color:#e82c20}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message.monsterinsights-addon-not-installed .interior.monsterinsights-addon-not-installed .addon-status span,#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error.monsterinsights-addon-not-installed .interior.monsterinsights-addon-not-installed .addon-status span{color:#a3a4a5}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message span.addon-status,#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error span.addon-status{float:left;font-weight:700}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message a.button,#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error a.button{float:right}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message span.monsterinsights-spinner,#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error span.monsterinsights-spinner{position:absolute;bottom:15px;right:0}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-action{display:inline;float:right}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-action .button-primary{margin:-5px 0 0;-webkit-border-radius:3px;-moz-border-radius:3px;-o-border-radius:3px;border-radius:3px}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-action .button-primary:hover{color:#23282d;background-color:#fafafa;border-color:#999}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error{bottom:10px;float:none;left:15px;right:20px;width:auto}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error .xinterior{width:100%;margin:0;background:#fff;border-left:4px solid #dc3232;box-shadow:0 1px 1px 0 rgba(0,0,0,0.1)}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error p{padding:10px;margin:5px 10px}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error .wrap{margin:0}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error .icon32{display:none}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error h2{padding:0}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error .form-table th{padding:10px 0;width:30%!important}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error .form-table input[type="text"],#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error .monsterinsights-addon .monsterinsights-addon-error .form-table input[type="password"]{width:100%!important}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-error p.submit{padding:0}
		#monsterinsights-addons .monsterinsights-addons-area .monsterinsights-addon p{color:#2f2f2f;font-size:13px;margin:10px 0 0;text-shadow:0 1px #fff}
		#monsterinsights-addons .monsterinsights-addons-area #monsterinsights-addons-unlock-more-area{margin:40px auto 20px;padding-bottom:0;border-bottom:0}
		#monsterinsights-addons-more-area .monsterinsights-addon .interior{padding:15px 20px!important}
		#monsterinsights-addons-refresh-addons-form{width:100%;max-width:850px;float:left}
		@media (min-width: 992px) and (max-width: 1199px) {
			#monsterinsights-addons-refresh-addons-form{max-width:450px}
		}
		@media (min-width: 768px) and (max-width: 991px) {
			#monsterinsights-addons-refresh-addons-form{max-width:50%}
			#monsterinsights-addons-refresh-addons-form input.button{display:block}
		}
		@media (min-width: 600px) and (max-width: 767px) {
			#monsterinsights-addons-refresh-addons-form{width:100%;float:none}
			#monsterinsights-addons-refresh-addons-form input.button{display:block}
		}
		#monsterinsights-filter-form{float:right}
		#monsterinsights-filter-form input[type='submit'],#monsterinsights-filter-form select{background-color:#f7f7f7;color:#23282d;border:1px solid #ddd;height:30px;width:120px;margin-top:-2px}
		#monsterinsights-filter-form input{padding:5px 15px;box-shadow:0;cursor:pointer;background-color:#f7f7f7;color:#23282d}
		#monsterinsights-filter-form input:hover{color:#23282d;background-color:#fafafa;border-color:#999}
		#monsterinsights-filter-form .spinner{float:left}
		@media only screen and (max-width: 1050px) {
			#monsterinsights-addons-area .monsterinsights-addon{width:49%}
			#monsterinsights-addons-area .monsterinsights-addon:nth-child(2n){margin-right:0}
			#monsterinsights-addons-area .monsterinsights-addon:nth-child(2n+1){clear:both}
			#monsterinsights-addons-area .monsterinsights-addon:nth-child(3n){margin-right:2%}
			#monsterinsights-addons-area .monsterinsights-addon:nth-child(3n+1){clear:none}
			#monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-excerpt{margin-bottom:90px}
		}
		@media only screen and (max-width: 782px) {
			#monsterinsights-addons-area .monsterinsights-addon{min-height:auto}
			#monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-action .button-primary{margin:-7px 0 0}
		}
		@media only screen and (max-width: 600px) {
			#monsterinsights-addons-area .monsterinsights-addon{width:99%}
			#monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message{float:left;width:100%}
			#monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message span.addon-status{display:block;width:100%;margin:0 0 5px;text-align:center}
			#monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message div.monsterinsights-addon-action{clear:both;display:block;width:100%;text-align:center}
			#monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-message div.monsterinsights-addon-action .button-primary{clear:both;float:none;margin:0 auto}
			#monsterinsights-addons-area .monsterinsights-addon .monsterinsights-addon-excerpt{margin-bottom:120px}
		}
	/** Network Addons Page Styles **/

	/** Single Site Addons Page Styles **/

/** Welcome Page Styles **/
	/** Generic Welcome Page Styles **/

	/** Welcome Tab Styles **/

	/** What's New Tab Styles **/

	/** Changelog Tab Styles **/

	/** Support Tab Styles **/